@@ -1,6 +1,8 @@
 """Interface to ECC signature algorithm and key-exchange."""
+import typing
 
-from ..backends import load_algorithm as _load_algo, Backends as _Backends
+from ..backends import Backends as _Backends
+from ..backends import load_algorithm as _load_algo
 
 
 def _load_ecc_cpr(backend):
@@ -8,9 +10,9 @@ def _load_ecc_cpr(backend):
     return _load_algo("ECC", backend)
 
 
-def generate(curve, *, backend=None):
+def generate(curve: str, *, backend: typing.Optional[_Backends] = None):
     """
-    Generate a private key with given curve `curve`.
+    Generate a private key with given curve ``curve``.
 
     Args:
         curve (str): The name of the curve to use.
@@ -20,17 +22,22 @@ def generate(curve, *, backend=None):
             The backend to use. It must be a value from :any:`Backends`.
 
     Returns:
-        :any:`BasePrivateKey`: An `ECCPrivateKey` interface.
+        BasePrivateKey: An ECC private key.
 
     Raises:
-        KeyError:
+        ValueError:
             if the curve is not supported by the backend or the name of the
             curve is invalid.
     """
-    return _load_ecc_cpr(backend).ECCPrivateKey(curve)
+    return _load_ecc_cpr(backend).generate(curve)
 
 
-def load_public_key(data, *, edwards=None, backend=None):
+def load_public_key(
+    data: typing.ByteString,
+    *,
+    edwards: bool = True,
+    backend: typing.Optional[_Backends] = None,
+):
     """Loads the public key and returns a Key interface.
 
     Args:
@@ -48,15 +55,22 @@ def load_public_key(data, *, edwards=None, backend=None):
             The backend to use. It must be a value from :any:`Backends`.
 
     Returns:
-        :any:`BasePublicKey`: An `ECCPublicKey` interface.
+        BasePublicKey: An ECC public key.
     """
     kwargs = dict()
     if len(data) == 32:
-        kwargs = dict(edwards=edwards)
-    return _load_ecc_cpr(backend).ECCPublicKey.load(data, **kwargs)
+        if backend == _Backends.CRYPTOGRAPHY:
+            kwargs = dict(edwards=edwards)
+    return _load_ecc_cpr(backend).load_public_key(data, **kwargs)
 
 
-def load_private_key(data, passphrase=None, *, edwards=None, backend=None):
+def load_private_key(
+    data: typing.ByteString,
+    passphrase: typing.Optional[typing.ByteString] = None,
+    *,
+    edwards: bool = True,
+    backend: typing.Optional[_Backends] = None,
+):
     """Loads the private key and returns a Key interface.
 
     If the private key was not encrypted duting the serialization,
@@ -65,8 +79,8 @@ def load_private_key(data, passphrase=None, *, edwards=None, backend=None):
     Args:
         data (bytes, bytearray):
             The private key (a bytes-like object) to deserialize.
-        password (bytes, bytearray):
-            The password (in bytes) that was used to encrypt the
+        passphrase (bytes, bytearray):
+            The passphrase (in bytes) that was used to encrypt the
             private key. `None` if the key was not encrypted.
 
     Keyword Arguments:
@@ -80,13 +94,13 @@ def load_private_key(data, passphrase=None, *, edwards=None, backend=None):
             The backend to use. It must be a value from `Backends`.
 
     Returns:
-        :any:`BasePrivateKey`: An ECCPrivateKey interface.
+        BasePrivateKey: An ECCPrivateKey interface.
     """
     kwargs = dict()
     if len(data) == 32:
         if backend == _Backends.CRYPTOGRAPHY:
             kwargs = dict(edwards=edwards)
-    return _load_ecc_cpr(backend).ECCPrivateKey.load(
+    return _load_ecc_cpr(backend).load_private_key(
         data,
         passphrase,
         **kwargs,
