@@ -1,4 +1,8 @@
 """Interface to RSA cipher and signature algorithm"""
+import typing
+
+from .. import base
+from ..backends import Backends as _Backends
 from ..backends import load_algorithm as _load_algo
 
 
@@ -7,11 +11,16 @@ def _load_rsa_cpr(backend):
     return _load_algo("RSA", backend)
 
 
-def generate(bits, e=65537, *, backend=None):
+def generate(
+    bits: int,
+    e: int = 65537,
+    *,
+    backend: typing.Optional[_Backends] = None,
+) -> base.BasePrivateKey:
     """
-    Generate a private key with given key modulus `bits` and
-    public exponent `e` (default 65537).
-    Recommended size of `bits` > 1024.
+    Generate a private key with given key modulus ``bits`` and public exponent
+    ``e`` (default 65537).
+    Recommended size of ``bits`` > 1024.
 
     Args:
         bits (int): The bit length of the RSA key.
@@ -22,12 +31,16 @@ def generate(bits, e=65537, *, backend=None):
             The backend to use. It must be a value from :any:`Backends`.
 
     Returns:
-        :any:`BasePrivateKey`: A `RSAPrivateKey` object.
+        BasePrivateKey: The RSA private key.
     """
-    return _load_rsa_cpr(backend).RSAPrivateKey(bits, e)
+    return _load_rsa_cpr(backend).generate(bits, e)
 
 
-def load_public_key(data, *, backend=None):
+def load_public_key(
+    data: typing.ByteString,
+    *,
+    backend: typing.Optional[_Backends] = None,
+) -> base.BasePublicKey:
     """Loads the public key and returns a Key interface.
 
     Args:
@@ -39,12 +52,17 @@ def load_public_key(data, *, backend=None):
             The backend to use. It must be a value from :any:`Backends`.
 
     Returns:
-        :any:`BasePublicKey`: An `RSAPublicKey` object.
+        BasePublicKey: The RSA public key.
     """
-    return _load_rsa_cpr(backend).RSAPublicKey.load(data)
+    return _load_rsa_cpr(backend).load_public_key(data)
 
 
-def load_private_key(data, passphrase=None, *, backend=None):
+def load_private_key(
+    data: typing.ByteString,
+    passphrase: typing.Optional[typing.ByteString] = None,
+    *,
+    backend: typing.Optional[_Backends] = None,
+) -> base.BasePrivateKey:
     """Loads the private key and returns a Key interface.
 
     If the private key was not encrypted duting the serialization,
@@ -54,14 +72,14 @@ def load_private_key(data, passphrase=None, *, backend=None):
         data (bytes, bytearray):
             The private key (a bytes-like object) to deserialize.
         passphrase (bytes, bytearray):
-            The password that was used to encrypt the private key.
-            `None` if the private key was not encrypted.
+            The passphrase that was used to encrypt the private key.
+            ``None`` if the private key was not encrypted.
 
     Keyword Arguments:
         backend (:class:`pyflocker.ciphers.backends.Backends`):
             The backend to use. It must be a value from :any:`Backends`.
 
     Returns:
-        :any:`BasePrivateKey`: A `RSAPrivateKey` object.
+        BasePrivateKey: The RSA private key.
     """
-    return _load_rsa_cpr(backend).RSAPrivateKey.load(data, passphrase)
+    return _load_rsa_cpr(backend).load_private_key(data, passphrase)
